@@ -165,10 +165,10 @@ def update_cellulase_and_nutrient_loading():
     
 pretreatment_sys = System('pretreatment_sys',
                path=(U101, T201, M201, M202, M203,
-                        R201, P201, T202, F201, M204,
-                        H201, M210, M205, T203, T203,
-                        H301,
-                        M301))
+                    R201, P201, T202, F201, M204,
+                    H201, M210, M205, T203, T203,
+                    H301,
+                    M301))
 
 # %% Fermentation system
 
@@ -249,17 +249,16 @@ D401-1-1-M401
 # Heat up before beer column
 # Exchange heat with stillage
 H401 = bst.HXprocess('H401', ins=(T302-0, None),
-                    fluid_type='ss', U=1.28)
+                     phase0='l', phase1='l', U=1.28)
 
 # Beer column
 xbot = Ethanol_molfrac(0.00001)
 ytop = Ethanol_molfrac(0.50)
-D402 = bst.BinaryDistillation('D402', ins=H401-0, k=1.25,
+D402 = bst.BinaryDistillation('D402', ins=H401-0, k=1.25, Rmin=0.6,
                        P=101325, y_top=ytop, x_bot=xbot,
                        LHK=('Ethanol', 'Water'))
 D402.tray_material = 'Stainless steel 304'
 D402.vessel_material = 'Stainless steel 304'
-D402.BM = 2.4
 D402.boiler.U = 1.85
 P401 = bst.Pump('P401', ins=D402-1)
 P401-0-1-H401
@@ -268,14 +267,13 @@ P401-0-1-H401
 M402 = bst.Mixer('M402', ins=(D402-0, None))
 
 ytop = Ethanol_molfrac(0.915)
-D403 = bst.BinaryDistillation('D403', ins=M402-0,
+D403 = bst.BinaryDistillation('D403', ins=M402-0, Rmin=0.6,
                        P=101325, y_top=ytop, x_bot=xbot,
                        k=1.25, LHK=('Ethanol', 'Water'))
 D403.tray_material = 'Stainless steel 304'
 D403.vessel_material = 'Stainless steel 304'
 D403.is_divided = True
 D403.boiler.U = 1.85
-D403.BM = 2.8
 P402 = bst.Pump('P402', ins=D403-1)
 
 JX = P402-0 - bst.Junction("JX") - 0**M201
@@ -431,7 +429,7 @@ splits = [('Ethanol', 1, 15),
 # tmo.Stream.default_ID_number = 600
 
 well_water = Stream('well_water', Water=1, T=15+273.15)
-M601 = bst.Mixer('M601', ins=(S401-1, '', '', ''))
+M601 = bst.Mixer('M601', ins=(S401-1, '', ''))
 J3 = H201-0 - bst.Junction('J3') - 1**M601
 
 WWTC = units.WasteWaterSystemCost('WWTC', ins=M601-0)
@@ -535,10 +533,12 @@ makeup_water = Stream('makeup_water', thermo=water_thermo, price=price['Makeup w
 PWC = bst.facilities.ProcessWaterCenter('PWC',
                                         (S604-0, makeup_water),
                                         (),
+                                        None,
                                         (BT-1, CT-1),
                                         process_water_streams)
-J4 = BT.outs[-1] - bst.Junction('J4') - 2**M601
-J5 = CT.outs[1] - bst.Junction('J5') - 3**M601
+blowdown_mixer = bst.BlowdownMixer('blowdown_mixer', ins=(), outs=2**M601)
+J4 = BT.outs[-1] - bst.Junction('J4') - 0**blowdown_mixer
+J5 = CT.outs[1] - bst.Junction('J5') - 1**blowdown_mixer
 
 Substance = tmo.Chemical.blank('Substance')
 Substance.at_state(phase='l')
@@ -571,13 +571,14 @@ FT = units.FireWaterTank('FT',
 # %% Complete system
 
 cornstover_sys = System('cornstover_sys',
-                        path=(pretreatment_sys, fermentation_sys, puresys, J2, S401,
-                                 J3, J4, J5, M601, WWTC, R601,
-                                 aerobic_digestion_sys, S604),
+                        path=(pretreatment_sys, fermentation_sys,
+                              puresys, J2, S401, J3, M601, WWTC, R601,
+                              aerobic_digestion_sys, S604),
                         facilities=(M501, CWP, BT, CT,
                                     PWC, ADP, update_lime_boilerchems_and_ash,
                                     CIP_package, S301, S302, DAP_storage,
-                                    CSL_storage, FT))
+                                    CSL_storage, FT, J4, J5, blowdown_mixer),
+                        facility_recycle=blowdown_mixer-0)
 cornstover_sys.products.add(ash)
 baghouse_bags = Stream(ID='Baghouse_bags', thermo=substance_thermo, flow=(1,), price=11.1)
 cornstover_sys.feeds.add(lime)
@@ -601,7 +602,9 @@ ethanol_tea = CornstoverTEA(
         finance_interest=0.08,
         finance_years=10,
         finance_fraction=0.4,
-        OSBL_units=(WWTC, CWP, CT, PWC, ADP), # BT not included
+        OSBL_units=(WWTC, CWP, CT, PWC, ADP,
+                    T701, T702, P701, P702, M701, FT,
+                    CSL_storage, DAP_storage), # BT not included
         warehouse=0.04, 
         site_development=0.09, 
         additional_piping=0.045,
@@ -654,7 +657,7 @@ Area800 = bst.TEA.like(System(None, (CWP, CT, PWC, ADP, CIP_package)),
 areas = (Area100, Area200, Area300, Area400,
          Area500, Area600, Area700, Area800)
 numbered_areas = tuple(enumerate(areas, 1))
-installation_costs = {i: j.installation_cost/1e6
+installed_costs = {i: j.installed_cost/1e6
                       for i,j in numbered_areas}
 utility_costs = {i: j.utility_cost/1e6
                  for i,j in numbered_areas}
@@ -673,7 +676,7 @@ get_rate = lambda units: sum([i.power_utility.rate
 get_ecost = lambda units: sum([i.power_utility.cost
                                for i in units])*24*350.4/1e6
 
-cooling_water_uses = {i: get_utility(j.units, 'Cooling water', 'duty')/1e6/4.184
+cooling_water_uses = {i: get_utility(j.units, 'cooling_water', 'duty')/1e6/4.184
                       for i,j in numbered_areas}
 
 electricity_uses = {i: get_rate(j.units)/41 for i,j in numbered_areas}
