@@ -1,9 +1,8 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 """
-Created on Thu Dec 21 11:05:24 2017
+The complete lipid-cane biorefinery system is created here.
 
-@author: Yoel
 """
 import numpy as np
 import biosteam as bst
@@ -122,13 +121,14 @@ H201 = units.HXutility('H201', T=343.15, V=0)
 
 # Mix in acid
 T203 = units.MixTank('T203')
+T203.tau = 0.10
 
 # Pump acid solution
 P201 = units.Pump('P201')
 
 # Mix lime solution
 T204 = units.MixTank('T204')
-T204.tau = 0.25
+T204.tau = 0.10
 P202 = units.Pump('P202')
 
 # Blend acid lipid solution with lime
@@ -318,7 +318,7 @@ M301 = units.Mixer('M301')
 H301 = units.HXutility('H301', T=295.15)
 
 # Ethanol Production
-R301 = units.Fermentation('R301', outs=('CO2', ''), tau=10, efficiency=0.90, N=6) 
+R301 = units.Fermentation('R301', outs=('CO2', ''), tau=9, efficiency=0.90, N=4) 
 T301 = units.StorageTank('T301', tau=4, vessel_material='Carbon steel')
 T301.line = 'Beer tank'
 
@@ -338,7 +338,7 @@ P301 = units.Pump('P301')
 # Heat up before beer column
 # Exchange heat with stillage
 H302 = units.HXprocess('H302', outs=('', 'stillage'),
-                     fluid_type='ss', U=1.28)
+                       phase0='l', phase1='l', U=1.28)
 
 # Beer column
 xbot = mass2molar_ethanol_fraction(0.00001)
@@ -746,6 +746,7 @@ CWP = units.ChilledWaterPackage('CWP')
 PWC = units.ProcessWaterCenter('PWC',
                                (M305-0, makeup_water),
                                (),
+                               None,
                                makeup_water_streams,
                                process_water_streams)
 
